exceptions/spotify_exceptions library

Exceptions / Errors

SpotifyAuthenticationException
Thrown when authentication, token swap, or token refresh fails.
SpotifyConnectionException
Thrown when connecting to Spotify App Remote fails or Spotify Remote is disconnected.
SpotifyException
Base exception class for all Spotify SDK errors.
SpotifyGeneralException
Generic Spotify SDK exception for uncategorized errors.
SpotifyImageException
Thrown when image / artwork fetching fails.
SpotifyLibraryException
Thrown when user library or capability operations fail.
SpotifyNotInstalledException
Thrown when Spotify app is not installed on the mobile host device.
SpotifyPlaybackException
Thrown when playback commands (play, pause, skip, seek, queue, repeat, shuffle) fail.
SpotifyUnimplementedException
Thrown when a method is not implemented on the current platform.