Logger class

A lightweight, WASM-compatible logging utility that replaces the heavy external logger package to avoid dart:io transitive imports.

Constructors

Logger({dynamic printer})
Creates a new Logger instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
printer → dynamic
Optional printer configuration (not used by this lightweight logger).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

e(String message) → void
Logs an error message.
i(String message) → void
Logs an info message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited