Album class

An album in the Spotify library.

Annotations
  • @JsonSerializable.new()

Constructors

Album(String? name, String? uri)
Constructor for Album.
Album.fromJson(Map<String, dynamic> json)
Converts a Map<String, dynamic> to an Album.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the album.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
The URI of the album.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts an Album to a Map<String, dynamic>.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited