ConnectionStatus class
The connection status of the Spotify SDK.
- Annotations
-
- @JsonSerializable.new()
Constructors
- ConnectionStatus(String? message, String? errorCode, String? errorDetails, {required bool connected})
- Constructor for ConnectionStatus.
-
ConnectionStatus.fromJson(Map<
String, dynamic> json) -
Converts a Map<String, dynamic> to a ConnectionStatus.
factory
Properties
- connected → bool
-
Whether the SDK is connected.
final
- errorCode → String?
-
The error code, if any.
final
- errorDetails → String?
-
The error details, if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
The status message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hasError(
) → bool - Returns whether the status represents an error.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts a ConnectionStatus to a Map<String, dynamic>.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited