CrossfadeState class

The crossfade state of the Spotify player.

Annotations
  • @JsonSerializable.new()

Constructors

CrossfadeState(int duration, {required bool isEnabled})
Constructor for CrossfadeState.
CrossfadeState.fromJson(Map<String, dynamic> json)
Converts a Map<String, dynamic> to a CrossfadeState.
factory

Properties

duration int
The duration of the crossfade in milliseconds.
final
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
Whether crossfade is enabled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts a CrossfadeState to a Map<String, dynamic>.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited