ImageUri class

A URI for an image in the Spotify library.

Annotations
  • @JsonSerializable.new()

Constructors

ImageUri(String raw)
Constructor for ImageUri.
ImageUri.fromJson(Map<String, dynamic> json)
Converts a Map<String, dynamic> to an ImageUri.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
raw String
The raw URI string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts an ImageUri to a Map<String, dynamic>.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited