linkedFromUri property
The URI of the track this one was linked from.
Implementation
@JsonKey(name: 'linked_from_uri', readValue: _readLinkedFromUri)
final String? linkedFromUri;
The URI of the track this one was linked from.
@JsonKey(name: 'linked_from_uri', readValue: _readLinkedFromUri)
final String? linkedFromUri;