UserStatus class

The status of a Spotify user.

Annotations
  • @JsonSerializable.new()

Constructors

UserStatus(int code, String shortMessage, String longMessage)
Constructor for UserStatus.
UserStatus.fromJson(Map<String, dynamic> json)
Converts a Map<String, dynamic> to a UserStatus.
factory

Properties

code int
The status code.
final
hashCode int
The hash code for this object.
no setterinherited
longMessage String
The long status message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortMessage String
The short status message.
final
statusCodeNotLoggedIn int
Status code for not logged in.
final
statusCodeOk int
Status code for OK.
final

Methods

isLoggedIn() bool
Returns whether the user is logged in.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts a UserStatus to a Map<String, dynamic>.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited