spotify_sdk_platform_interface library

Classes

Album
An album in the Spotify library.
Artist
An artist in the Spotify library.
Capabilities
The capabilities of a Spotify user.
ConnectionStatus
The connection status of the Spotify SDK.
CrossfadeState
The crossfade state of the Spotify player.
ImageUri
A URI for an image in the Spotify library.
LibraryState
The library state of a Spotify item.
MethodChannelSpotifySdk
An implementation of SpotifySdkPlatform that uses method channels.
PlayerContext
The context of the Spotify player.
PlayerOptions
The playback options of the Spotify player.
PlayerRestrictions
The playback restrictions of the Spotify player.
PlayerState
The state of the Spotify player.
SpotifySdkPlatform
The interface that implementations of spotify_sdk must implement.
Track
A track in the Spotify library.
UserStatus
The status of a Spotify user.

Enums

ImageDimension
Holds the values from the spotify api for supported Image dimensions
PodcastPlaybackSpeed
Holds the values from the spotify api for supported Podcast playback speeds
SpotifyRepeatMode
Holds the values from the spotify api for RepeatModes

Exceptions / Errors

SpotifyAuthenticationException
Thrown when authentication, token swap, or token refresh fails.
SpotifyConnectionException
Thrown when connecting to Spotify App Remote fails or Spotify Remote is disconnected.
SpotifyException
Base exception class for all Spotify SDK errors.
SpotifyGeneralException
Generic Spotify SDK exception for uncategorized errors.
SpotifyImageException
Thrown when image / artwork fetching fails.
SpotifyLibraryException
Thrown when user library or capability operations fail.
SpotifyNotInstalledException
Thrown when Spotify app is not installed on the mobile host device.
SpotifyPlaybackException
Thrown when playback commands (play, pause, skip, seek, queue, repeat, shuffle) fail.
SpotifyUnimplementedException
Thrown when a method is not implemented on the current platform.