Capabilities class
The capabilities of a Spotify user.
- Annotations
-
- @JsonSerializable.new()
Constructors
- Capabilities({required bool canPlayOnDemand})
- Constructor for Capabilities.
-
Capabilities.fromJson(Map<
String, dynamic> json) -
Converts a Map<String, dynamic> to a Capabilities.
factory
Properties
- canPlayOnDemand → bool
-
Whether the user can play tracks on demand.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts a Capabilities to a Map<String, dynamic>.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited