LibraryState class

The library state of a Spotify item.

Annotations
  • @JsonSerializable.new()

Constructors

LibraryState(String uri, {required bool isSaved, required bool canSave})
Constructor for LibraryState.
LibraryState.fromJson(Map<String, dynamic> json)
Converts a Map<String, dynamic> to a LibraryState.
factory

Properties

canSave bool
Whether the user can save the item.
final
hashCode int
The hash code for this object.
no setterinherited
isSaved bool
Whether the item is saved in the library.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
The URI of the item.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts a LibraryState to a Map<String, dynamic>.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited