PlayerContext class

The context of the Spotify player.

Annotations
  • @JsonSerializable.new()

Constructors

PlayerContext(String title, String subtitle, String type, String uri)
Constructor for PlayerContext.
PlayerContext.fromJson(Map<String, dynamic> json)
Converts a Map<String, dynamic> to a PlayerContext.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
The subtitle of the context.
final
title String
The title of the context.
final
type String
The type of the context.
final
uri String
The URI of the context.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts a PlayerContext to a Map<String, dynamic>.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited