PlayerOptions class
The playback options of the Spotify player.
- Annotations
-
- @JsonSerializable.new()
Constructors
- PlayerOptions(SpotifyRepeatMode repeatMode, {required bool isShuffling})
- Constructor for PlayerOptions.
-
PlayerOptions.fromJson(Map<
String, dynamic> json) -
Converts a Map<String, dynamic> to a PlayerOptions.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isShuffling → bool
-
Whether shuffle is enabled.
final
- repeatMode → SpotifyRepeatMode
-
The current repeat mode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts a PlayerOptions to a Map<String, dynamic>.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited