PlayerRestrictions class

The playback restrictions of the Spotify player.

Annotations
  • @JsonSerializable.new()

Constructors

PlayerRestrictions({required bool canSkipNext, required bool canSkipPrevious, required bool canRepeatTrack, required bool canRepeatContext, required bool canToggleShuffle, required bool canSeek})
Constructor for PlayerRestrictions.
PlayerRestrictions.fromJson(Map<String, dynamic> json)
Converts a Map<String, dynamic> to a PlayerRestrictions.
factory

Properties

canRepeatContext bool
Whether repeating the current context is allowed.
final
canRepeatTrack bool
Whether repeating the current track is allowed.
final
canSeek bool
Whether seeking is allowed.
final
canSkipNext bool
Whether skipping to the next track is allowed.
final
canSkipPrevious bool
Whether skipping to the previous track is allowed.
final
canToggleShuffle bool
Whether toggling shuffle is allowed.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts a PlayerRestrictions to a Map<String, dynamic>.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited